aboutsummaryrefslogtreecommitdiffstats
path: root/src/rlx_util.erl
diff options
context:
space:
mode:
Diffstat (limited to 'src/rlx_util.erl')
-rw-r--r--src/rlx_util.erl10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/rlx_util.erl b/src/rlx_util.erl
index 4afb26d..c2b2081 100644
--- a/src/rlx_util.erl
+++ b/src/rlx_util.erl
@@ -19,7 +19,7 @@
%%% @copyright (C) 2012 Erlware, LLC.
%%%
%%% @doc Trivial utility file to help handle common tasks
--module(rcl_util).
+-module(rlx_util).
-export([mkdir_p/1,
to_binary/1,
@@ -66,12 +66,12 @@ to_string(Atom) when erlang:is_atom(Atom) ->
to_string(Else) when erlang:is_list(Else) ->
Else.
-%% @doc get the reason for a particular relcool error
--spec error_reason(relcool:error()) -> any().
+%% @doc get the reason for a particular relx error
+-spec error_reason(relx:error()) -> any().
error_reason({error, {_, Reason}}) ->
Reason.
-%% @doc check to see if the value is a relcool error
--spec is_error(relcool:error() | any()) -> boolean().
+%% @doc check to see if the value is a relx error
+-spec is_error(relx:error() | any()) -> boolean().
is_error({error, _}) ->
true;
is_error(_) ->